@@ -1,9 +1,7 @@
 use core::marker;
 
 use crate::integer_encoding::{IntegerEncoding, UsizeEncoding};
-use musli::en::{
-    Encoder, MapEncoder, PackEncoder, SequenceEncoder, StructEncoder, TupleEncoder, VariantEncoder,
-};
+use musli::en::{Encoder, PackEncoder, PairEncoder, SequenceEncoder, VariantEncoder};
 use musli_binary_common::writer::Writer;
 
 /// A very simple encoder.
@@ -255,75 +253,23 @@ where
     }
 }
 
-impl<'a, W, I, L> MapEncoder for StorageEncoder<'a, W, I, L>
+impl<'a, W, I, L> PairEncoder for StorageEncoder<'a, W, I, L>
 where
     W: Writer,
     I: IntegerEncoding,
     L: UsizeEncoding,
 {
     type Error = W::Error;
-    type Key<'this> = StorageEncoder<'this, W, I, L> where Self: 'this;
-    type Value<'this> = StorageEncoder<'this, W, I, L> where Self: 'this;
+    type First<'this> = StorageEncoder<'this, W, I, L> where Self: 'this;
+    type Second<'this> = StorageEncoder<'this, W, I, L> where Self: 'this;
 
     #[inline]
-    fn encode_key(&mut self) -> Result<Self::Key<'_>, Self::Error> {
+    fn encode_first(&mut self) -> Result<Self::First<'_>, Self::Error> {
         Ok(StorageEncoder::new(self.writer))
     }
 
     #[inline]
-    fn encode_value(&mut self) -> Result<Self::Value<'_>, Self::Error> {
-        Ok(StorageEncoder::new(self.writer))
-    }
-
-    #[inline]
-    fn finish(self) -> Result<(), Self::Error> {
-        Ok(())
-    }
-}
-
-impl<'a, W, I, L> StructEncoder for StorageEncoder<'a, W, I, L>
-where
-    W: Writer,
-    I: IntegerEncoding,
-    L: UsizeEncoding,
-{
-    type Error = W::Error;
-    type FieldTag<'this> = StorageEncoder<'this, W, I, L> where Self: 'this;
-    type FieldValue<'this> = StorageEncoder<'this, W, I, L> where Self: 'this;
-
-    #[inline]
-    fn encode_field_tag(&mut self) -> Result<Self::FieldTag<'_>, Self::Error> {
-        Ok(StorageEncoder::new(self.writer))
-    }
-
-    #[inline]
-    fn encode_field_value(&mut self) -> Result<Self::FieldValue<'_>, Self::Error> {
-        Ok(StorageEncoder::new(self.writer))
-    }
-
-    #[inline]
-    fn finish(self) -> Result<(), Self::Error> {
-        Ok(())
-    }
-}
-
-impl<'a, W, I, L> TupleEncoder for StorageEncoder<'a, W, I, L>
-where
-    W: Writer,
-    I: IntegerEncoding,
-    L: UsizeEncoding,
-{
-    type Error = W::Error;
-    type FieldTag<'this> = StorageEncoder<'this, W, I, L> where Self: 'this;
-    type FieldValue<'this> = StorageEncoder<'this, W, I, L> where Self: 'this;
-
-    #[inline]
-    fn encode_field_tag(&mut self) -> Result<Self::FieldTag<'_>, Self::Error> {
-        Ok(StorageEncoder::new(self.writer))
-    }
-
-    #[inline]
-    fn encode_field_value(&mut self) -> Result<Self::FieldValue<'_>, Self::Error> {
+    fn encode_second(&mut self) -> Result<Self::Second<'_>, Self::Error> {
         Ok(StorageEncoder::new(self.writer))
     }
 
